@@ -45,7 +45,8 @@ class Levenshtein():
     def __init__(self):
         pass
 
-    def levenshtein(a,b):
+    @staticmethod
+    def length(a,b):
         """
         Calculates the Levenshtein distance between a and b.
         """
@@ -67,6 +68,7 @@ class Levenshtein():
 
         return current[n]
 
+    @staticmethod
     def suggestion(original, searchable, number_of_matches = 3):
         """
         Compares a string to a list a strings and returns
@@ -75,7 +77,7 @@ class Levenshtein():
         distances = []
 
         for txt in searchable:
-            set = (levenshtein(original, txt), txt)
+            set = (Levenshtein.length(original, txt), txt)
             distances.append(set)
 
         distances.sort()
